@@ -29,6 +29,7 @@
 #include <test_assert.h>
 #include <test_color.h>
 #include "../emscripten_filesystem.h"
+#include "../load_kmx_file.hpp"
 
 #include "kmx_test_source.hpp"
 
@@ -70,7 +71,7 @@ apply_action(
     ) {
   switch (act.type) {
   case KM_CORE_IT_END:
-    assert(false);
+    test_assert(false);
     break;
   case KM_CORE_IT_ALERT:
     g_beep_found = true;
@@ -109,11 +110,11 @@ apply_action(
     // in a table. Or, if Keyman has a cached context, then there may be
     // additional text in the text store that Keyman can't see.
     if (act.backspace.expected_type == KM_CORE_BT_MARKER) {
-      assert(!context.empty());
-      assert(context.back().type == KM_CORE_CT_MARKER);
+      test_assert(!context.empty());
+      test_assert(context.back().type == KM_CORE_CT_MARKER);
       context.pop_back();
     } else if (text_store.length() > 0) {
-      assert(!context.empty() && !text_store.empty());
+      test_assert(!context.empty() && !text_store.empty());
       km_core_usv ch = text_store.back();
       text_store.pop_back();
       if (text_store.length() > 0 && Uni_IsSurrogate2(ch)) {
@@ -125,10 +126,10 @@ apply_action(
           text_store.pop_back();
         }
       }
-      assert(ch == act.backspace.expected_value);
+      test_assert(ch == act.backspace.expected_value);
 
-      assert(context.back().type == KM_CORE_CT_CHAR);
-      assert(context.back().character == ch);
+      test_assert(context.back().type == KM_CORE_CT_CHAR);
+      test_assert(context.back().character == ch);
       context.pop_back();
     }
     break;
@@ -163,7 +164,7 @@ apply_action(
     test_source.set_caps_lock_on(act.capsLock);
     break;
   default:
-    assert(false);  // NOT SUPPORTED
+    test_assert(false);  // NOT SUPPORTED
     break;
   }
 }
@@ -191,7 +192,8 @@ run_test(const km::core::path &source, const km::core::path &compiled) {
   km_core_keyboard * test_kb = nullptr;
   km_core_state * test_state = nullptr;
 
-  try_status(km_core_keyboard_load(compiled.c_str(), &test_kb));
+  auto blob = km::tests::load_kmx_file(compiled.native().c_str());
+  try_status(km_core_keyboard_load_from_blob(compiled.stem().c_str(), blob.data(), blob.size(), &test_kb));
 
   // Setup state, environment
   try_status(km_core_state_create(test_kb, test_env_opts, &test_state));
@@ -246,22 +248,22 @@ run_test(const km::core::path &source, const km::core::path &compiled) {
     size_t n = 0;
     try_status(km_core_context_get(km_core_state_context(test_state), &citems));
     try_status(context_items_to_utf16(citems, nullptr, &n));
-    km_core_cp *core_context_str = new km_core_cp[n];
+    km_core_cu *core_context_str = new km_core_cu[n];
     try_status(context_items_to_utf16(citems, core_context_str, &n));
 
     // Verify that both our local test_context and the core's test_state.context have
     // not diverged
     auto ci = citems;
     for(auto test_ci = test_context.begin(); ci->type != KM_CORE_CT_END || test_ci != test_context.end(); ci++, test_ci++) {
-      assert(ci->type != KM_CORE_CT_END && test_ci != test_context.end()); // Verify that both lists are same length
-      assert(test_ci->type == ci->type && test_ci->marker == ci->marker);
+      test_assert(ci->type != KM_CORE_CT_END && test_ci != test_context.end()); // Verify that both lists are same length
+      test_assert(test_ci->type == ci->type && test_ci->marker == ci->marker);
     }
     km_core_context_items_dispose(citems);
     if ((!context_invalidated) && (text_store != core_context_str)) {
       std::cerr << "text store has unexpectedly diverged from core_context" << std::endl;
       std::cerr << "text store  : " << string_to_hex(text_store) << " [" << text_store << "]" << std::endl;
       std::cerr << "core context: " << string_to_hex(core_context_str) << " [" << core_context_str << "]" << std::endl;
-     assert(false);
+     test_assert(false);
     }
   }
 
@@ -273,15 +275,15 @@ run_test(const km::core::path &source, const km::core::path &compiled) {
   size_t n = 0;
   try_status(km_core_context_get(km_core_state_context(test_state), &citems));
   try_status(context_items_to_utf16(citems, nullptr, &n));
-  km_core_cp *core_context_str = new km_core_cp[n];
+  km_core_cu *core_context_str = new km_core_cu[n];
   try_status(context_items_to_utf16(citems, core_context_str, &n));
 
   // Verify that both our local test_context and the core's test_state.context have
   // not diverged
   auto ci = citems;
   for(auto test_ci = test_context.begin(); ci->type != KM_CORE_CT_END || test_ci != test_context.end(); ci++, test_ci++) {
-    assert(ci->type != KM_CORE_CT_END && test_ci != test_context.end()); // Verify that both lists are same length
-    assert(test_ci->type == ci->type && test_ci->marker == ci->marker);
+    test_assert(ci->type != KM_CORE_CT_END && test_ci != test_context.end()); // Verify that both lists are same length
+    test_assert(test_ci->type == ci->type && test_ci->marker == ci->marker);
   }
 
   km_core_context_items_dispose(citems);
@@ -301,7 +303,7 @@ run_test(const km::core::path &source, const km::core::path &compiled) {
   for (auto it = options.begin(); it != options.end(); it++) {
     if (it->type == km::tests::KOT_OUTPUT) {
       std::cout << "output option-key: " << it->key << " expected: " << it->value;
-      km_core_cp const *value;
+      km_core_cu const *value;
       try_status(km_core_state_option_lookup(test_state, KM_CORE_OPT_KEYBOARD, it->key.c_str(), &value));
       std::cout << " actual: " << value << std::endl;
       if (it->value.compare(value) != 0) return __LINE__;
