@@ -2,13 +2,13 @@
 ## START STANDARD BUILD SCRIPT INCLUDE
 # adjust relative paths as necessary
 THIS_SCRIPT="$(readlink -f "${BASH_SOURCE[0]}")"
-. "${THIS_SCRIPT%/*}/../../../resources/build/build-utils.sh"
+. "${THIS_SCRIPT%/*}/../../../resources/build/builder.inc.sh"
 ## END STANDARD BUILD SCRIPT INCLUDE
 
 CORE_ROOT="$KEYMAN_ROOT/core"
 CORE_H_FILE="$CORE_ROOT/include/keyman/keyman_core_api.h"
 CORE_H_DOC="index.md"
-OUTPATH="$CORE_ROOT/build/doc"
+OUTPATH="$CORE_ROOT/build/docs/internal"
 
 ################################ Main script ################################
 
