@@ -19,7 +19,8 @@ builder_describe \
   "uninstall                 uninstall artifacts" \
   "--no-integration          don't run integration tests" \
   "--report                  create coverage report" \
-  "--coverage                capture test coverage"
+  "--coverage                capture test coverage" \
+  "--no-werror               don't report warnings as errors"
 
 builder_parse "$@"
 
@@ -42,6 +43,11 @@ else
 fi
 MESON_PATH="build/$(uname -m)/$MESON_TARGET"
 
+MESON_ARGS=--werror
+if builder_has_option --no-werror; then
+  MESON_ARGS=
+fi
+
 clean_action() {
   rm -rf "$THIS_SCRIPT_PATH/build/"
 }
@@ -60,13 +66,13 @@ check_missing_coverage_configuration() {
 }
 
 configure_action() {
-  # shellcheck disable=SC2086,SC2154
-  meson setup ${MESON_COVERAGE} --werror --buildtype $MESON_TARGET "${builder_extra_params[@]}" "$MESON_PATH"
+  # shellcheck disable=SC2086,SC2154,SC2248
+  meson setup ${MESON_COVERAGE} ${MESON_ARGS} --buildtype ${MESON_TARGET} "${builder_extra_params[@]}" "${MESON_PATH}"
 }
 
 test_action() {
   # shellcheck disable=SC2086,SC2154
-  meson test --print-errorlogs $builder_verbose
+  meson test --print-errorlogs ${builder_verbose}
   if builder_has_option --coverage; then
     # Note: requires lcov > 1.16 to properly work (see https://github.com/mesonbuild/meson/issues/6747)
     ninja coverage-html
@@ -88,7 +94,7 @@ fi
 builder_run_action clean       clean_action
 builder_run_action configure   configure_action
 
-[ -d "$MESON_PATH" ] && cd "$MESON_PATH"
+[[ -d "${MESON_PATH}" ]] && cd "${MESON_PATH}"
 
 builder_run_action build       ninja
 builder_run_action test        test_action
